@@ -8,8 +8,6 @@ import numpy as np
 import pandas as pd
 import pylab
 from scipy import optimize
-from scipy.optimize import differential_evolution
-from math import inf
 from math import isfinite
 import matplotlib.pyplot as plt
 from numpy import argmin
@@ -22,6 +20,7 @@ from numpy import ravel
 from numpy import array
 from numpy import append
 from numpy import min, max
+from spotPython.utils.init import fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
 from spotPython.utils.compare import selectNew
 from spotPython.utils.aggregate import aggregate_mean_var
 from spotPython.utils.repair import remove_nan
@@ -31,12 +30,11 @@ import time
 from spotPython.utils.progress import progress_bar
 from spotPython.utils.convert import find_indices
 from spotPython.hyperparameters.values import (
-    set_control_key_value,
     get_control_key_value,
     get_ith_hyperparameter_name_from_fun_control,
 )
 import plotly.graph_objects as go
-from typing import Union, Callable, Dict
+from typing import Callable
 
 
 logger = logging.getLogger(__name__)
@@ -61,10 +59,10 @@ class Spot:
 
     The `Spot` class is built in a modular manner. It combines the following components:
 
-        1. Design
-        2. Surrogate
-        3. Fun (objective function)
-        4. Optimizer
+        1. Fun (objective function)
+        2. Design (experimental design)
+        3. Optimizer to be used on the surrogate model
+        4. Surrogate (model)
 
     For each of the components different implementations can be selected and combined.
     Internal components are selected as default.
@@ -73,66 +71,26 @@ class Spot:
     Args:
         fun (Callable):
             objective function
-        lower (np.array): lower bound
-        upper (np.array): upper bound
-        fun_evals (int):
-            number of function evaluations
-        fun_repeats (int):
-            number of repeats (replicates).
-        max_time (int):
-            maximum time (in minutes)
-        noise (bool):
-            deterministic or noisy objective function
-        tolerance_x (float):
-            tolerance for new x solutions. Minimum distance of new solutions,
-            generated by `suggest_new_X`, to already existing solutions.
-            If zero (which is the default), every new solution is accepted.
-        ocba_delta (int):
-            OCBA increment (only used if `noise==True`)
-        var_type (List[str]):
-            list of type information, can be either "int", "num" or "factor"
-        var_name (List[str]):
-            list of variable names, e.g., ["x1", "x2"]
-        infill_criterion (str):
-            Can be `"y"`, `"s"`, `"ei"` (negative expected improvement), or `"all"`.
-        n_points (int):
-            number of infill points
-        seed (int):
-            initial seed
-        log_level (int):
-            log level with the following settings:
-            `NOTSET` (`0`),
-            `DEBUG` (`10`: Detailed information, typically of interest only when diagnosing problems.),
-            `INFO` (`20`: Confirmation that things are working as expected.),
-            `WARNING` (`30`: An indication that something unexpected happened, or indicative of some problem in the near
-                future (e.g. ‘disk space low’). The software is still working as expected.),
-            `ERROR` (`40`: Due to a more serious problem, the software has not been able to perform some function.), and
-            `CRITICAL` (`50`: A serious error, indicating that the program itself may be unable to continue running.)
-        show_models (bool):
-            Plot model. Currently only 1-dim functions are supported. Default is `False`.
-        show_progress (bool):
-            Show progress bar. Default is `True`.
+        fun_control (Dict[str, Union[int, float]]):
+            objective function information stored as a dictionary.
+            Default value is `fun_control_init()`.
         design (object):
-            experimental design.
+            experimental design. If `None`, spotPython's `spacefilling` is used.
+            Default value is `None`.
         design_control (Dict[str, Union[int, float]]):
-            experimental design information stored as a dictionary with the following entries:
-            "init_size": `10`, "repeats": `1`.
-        surrogate (object):
-            surrogate model. If `None`, spotPython's `kriging` is used.
-        surrogate_control (Dict[str, Union[int, float]]):
-            surrogate model information stored as a dictionary with the following entries:
-            "model_optimizer": `differential_evolution`,
-            "model_fun_evals": `None`,
-            "min_theta": `-3.`,  "max_theta": `3.`,
-            "n_theta": `1`,
-            "n_p": `1`,
-            "optim_p": `False`,
-            "var_type": `self.var_type`.
+            experimental design information stored as a dictionary.
+            Default value is `design_control_init()`.
         optimizer (object):
-            optimizer. If `None`, `scipy.optimize`'s `differential_evolution` is used.
+            optimizer on the surrogate. If `None`, `scipy.optimize`'s `differential_evolution` is used.
+            Default value is `None`.
         optimizer_control (Dict[str, Union[int, float]]):
-            information about the optimizer stored as a dictionary with the following entries:
-            "max_iter": `1000`.
+            information about the optimizer stored as a dictionary.
+            Default value is `optimizer_control_init()`.
+        surrogate (object):
+            surrogate model. If `None`, spotPython's `kriging` is used. Default value is `None`.
+        surrogate_control (Dict[str, Union[int, float]]):
+            surrogate model information stored as a dictionary.
+            Default value is `surrogate_control_init()`.
 
     Returns:
         (NoneType): None
@@ -147,6 +105,11 @@ class Spot:
         >>> import numpy as np
             from math import inf
             from spotPython.spot import spot
+            from spotPython.utils.init import (
+                fun_control_init,
+                design_control_init,
+                surrogate_control_init,
+                optimizer_control_init)
             def objective_function(X, fun_control=None):
                 if not isinstance(X, np.ndarray):
                     X = np.array(X)
@@ -156,11 +119,9 @@ class Spot:
                 x1 = X[:, 1]
                 y = x0**2 + 10*x1**2
                 return y
-            lower = np.array([0, 0])
-            upper = np.array([10, 10])
-            spot = spot.Spot(fun=objective_function,
-                        lower=lower,
-                        upper=upper,
+            fun_control = fun_control_init(
+                        lower = np.array([0, 0])
+                        upper = np.array([10, 10])
                         fun_evals=8,
                         fun_repeats=1,
                         max_time=inf,
@@ -173,18 +134,29 @@ class Spot:
                         seed=123,
                         log_level=20,
                         show_models=False,
-                        show_progress=True,
-                        design_control={"init_size": 5, "repeats": 1},
-                        surrogate_control={"model_fun_evals": 1000,
-                                        "min_theta": -3.,
-                                        "max_theta": 3.,
-                                        "n_theta": 2,
-                                        "theta_init_zero": True,
-                                        "n_p": 1,
-                                        "optim_p": False,
-                                        "var_type": ["num", "num"],
-                                        "seed": 124,},
-                        optimizer_control={"max_iter": 1000})
+                        show_progress=True)
+            design_control = design_control_init(
+                        init_size=5,
+                        repeats=1)
+            surrogate_control = surrogate_control_init(
+                        model_optimizer=differential_evolution,
+                        model_fun_evals=10000,
+                        min_theta=-3,
+                        max_theta=3,
+                        n_theta=2,
+                        theta_init_zero=True,
+                        n_p=1,
+                        optim_p=False,
+                        var_type=["num", "num"],
+                        seed=124)
+            optimizer_control = optimizer_control_init(
+                        max_iter=1000,
+                        seed=125)
+            spot = spot.Spot(fun=objective_function,
+                        fun_control=fun_control,
+                        design_control=design_control,
+                        surrogate_control=surrogate_control,
+                        optimizer_control=optimizer_control)
             spot.run()
             spot.plot_progress()
             spot.plot_contour(i=0, j=1)
@@ -196,32 +168,20 @@ class Spot:
 
     def __init__(
         self,
-        fun: Callable = None,
-        lower: np.array = None,
-        upper: np.array = None,
-        fun_evals: int = 15,
-        fun_repeats: int = 1,
-        fun_control: dict = {},
-        max_time: int = inf,
-        noise: bool = False,
-        tolerance_x: float = 0,
-        var_type: list = ["num"],
-        var_name: list = None,
-        infill_criterion: str = "y",
-        n_points: int = 1,
-        ocba_delta: int = 0,
-        seed: int = 123,
-        sigma: float = 0.0,
-        log_level: int = 50,
-        show_models: bool = False,
-        show_progress: bool = True,
         design: object = None,
-        design_control: Dict[str, Union[int, float]] = {},
-        surrogate: object = None,
-        surrogate_control: Dict[str, Union[int, float]] = {},
+        design_control: dict = design_control_init(),
+        fun: Callable = None,
+        fun_control: dict = fun_control_init(),
         optimizer: object = None,
-        optimizer_control: Dict[str, Union[int, float]] = {},
+        optimizer_control: dict = optimizer_control_init(),
+        surrogate: object = None,
+        surrogate_control: dict = surrogate_control_init(),
     ):
+        self.fun_control = fun_control
+        self.design_control = design_control
+        self.optimizer_control = optimizer_control
+        self.surrogate_control = surrogate_control
+
         # small value:
         self.eps = sqrt(spacing(1))
 
@@ -233,23 +193,12 @@ class Spot:
 
         # 1. fun_control updates:
         # -----------------------
-        self.fun_control = fun_control
-
-        # set fun_control["sigma"] to sigma if "sigma" is not in fun_control dictionary
-        # If no fun_control is provided, the fun_control dictionary is initialized with the
-        # key "sigma" and the value sigma amd the key "seed" and the value seed.
-        # This is a mimimum requirement for the fun_control dictionary to call
-        # objective functions from the spotPython.fun.objectivefunctions module.
-        set_control_key_value(control_dict=self.fun_control, key="sigma", value=sigma)
-        set_control_key_value(control_dict=self.fun_control, key="seed", value=seed)
         # Random number generator:
         self.rng = default_rng(self.fun_control["seed"])
 
         # 2. lower attribute updates:
         # -----------------------
         # if lower is in the fun_control dictionary, use the value of the key "lower" as the lower bound
-        # else use the lower bound lower
-        self.lower = lower
         if get_control_key_value(control_dict=self.fun_control, key="lower") is not None:
             self.lower = get_control_key_value(control_dict=self.fun_control, key="lower")
         # Number of dimensions is based on lower
@@ -258,14 +207,13 @@ class Spot:
         # 3. upper attribute updates:
         # -----------------------
         # if upper is in fun_control dictionary, use the value of the key "upper" as the upper bound
-        # else use the upper bound upper
-        self.upper = upper
         if get_control_key_value(control_dict=self.fun_control, key="upper") is not None:
             self.upper = get_control_key_value(control_dict=self.fun_control, key="upper")
 
         # 4. var_type attribute updates:
         # -----------------------
-        self.set_self_attribute("var_type", var_type, self.fun_control)
+        # self.set_self_attribute("var_type", var_type, self.fun_control)
+        self.var_type = self.fun_control["var_type"]
         # Force numeric type as default in every dim:
         # assume all variable types are "num" if "num" is
         # specified less than k times
@@ -275,7 +223,8 @@ class Spot:
 
         # 5. var_name attribute updates:
         # -----------------------
-        self.set_self_attribute("var_name", var_name, self.fun_control)
+        # self.set_self_attribute("var_name", var_name, self.fun_control)
+        self.var_name = self.fun_control["var_name"]
         # use x0, x1, ... as default variable names:
         if self.var_name is None:
             self.var_name = ["x" + str(i) for i in range(len(self.lower))]
@@ -286,17 +235,17 @@ class Spot:
 
         # 6. Additional self attributes updates:
         # -----------------------
-        self.set_self_attribute("fun_evals", fun_evals, self.fun_control)
-        self.set_self_attribute("fun_repeats", fun_repeats, self.fun_control)
-        self.set_self_attribute("max_time", max_time, self.fun_control)
-        self.set_self_attribute("noise", noise, self.fun_control)
-        self.set_self_attribute("tolerance_x", tolerance_x, self.fun_control)
-        self.set_self_attribute("ocba_delta", ocba_delta, self.fun_control)
-        self.set_self_attribute("log_level", log_level, self.fun_control)
-        self.set_self_attribute("show_models", show_models, self.fun_control)
-        self.set_self_attribute("show_progress", show_progress, self.fun_control)
-        self.set_self_attribute("infill_criterion", infill_criterion, self.fun_control)
-        self.set_self_attribute("n_points", n_points, self.fun_control)
+        self.fun_evals = self.fun_control["fun_evals"]
+        self.fun_repeats = self.fun_control["fun_repeats"]
+        self.max_time = self.fun_control["max_time"]
+        self.noise = self.fun_control["noise"]
+        self.tolerance_x = self.fun_control["tolerance_x"]
+        self.ocba_delta = self.fun_control["ocba_delta"]
+        self.log_level = self.fun_control["log_level"]
+        self.show_models = self.fun_control["show_models"]
+        self.show_progress = self.fun_control["show_progress"]
+        self.infill_criterion = self.fun_control["infill_criterion"]
+        self.n_points = self.fun_control["n_points"]
 
         # if the key "spot_writer" is not in the dictionary fun_control,
         # set self.spot_writer to None else to the value of the key "spot_writer"
@@ -313,25 +262,30 @@ class Spot:
         self.design = design
         if design is None:
             self.design = spacefilling(k=self.lower.size, seed=self.fun_control["seed"])
-        self.design_control = {"init_size": 10, "repeats": 1}
-        self.design_control.update(design_control)
+        # self.design_control = {"init_size": 10, "repeats": 1}
+        # self.design_control.update(design_control)
+
+        # Optimizer related information:
+        self.optimizer = optimizer
+        # self.optimizer_control = {"max_iter": 1000, "seed": 125}
+        # self.optimizer_control.update(optimizer_control)
+        if self.optimizer is None:
+            self.optimizer = optimize.differential_evolution
 
         # Surrogate related information:
         self.surrogate = surrogate
-        self.surrogate_control = {
-            "noise": self.noise,
-            "model_optimizer": differential_evolution,
-            "model_fun_evals": None,
-            "min_theta": -3.0,
-            "max_theta": 3.0,
-            "n_theta": 1,
-            "theta_init_zero": True,
-            "n_p": 1,
-            "optim_p": False,
-            "var_type": self.var_type,
-            "seed": 124,
-        }
-        self.surrogate_control.update(surrogate_control)
+        self.surrogate_control.update({"var_type": self.var_type})
+        # Surrogate control updates:
+        # The default value for `noise` from the surrogate_control dictionary
+        # based on surrogate_control.init() is None. This value is updated
+        # to the value of the key "noise" from the fun_control dictionary.
+        # If the value is set (i.e., not None), it is not updated.
+        if self.surrogate_control["noise"] is None:
+            self.surrogate_control.update({"noise": self.fun_control.noise})
+        if self.surrogate_control["model_fun_evals"] is None:
+            self.surrogate_control.update({"model_fun_evals": self.optimizer_control["max_iter"]})
+        if self.surrogate_control["model_optimizer"] is None:
+            self.surrogate_control.update({"model_optimizer": self.optimizer})
 
         # If self.surrogate_control["n_theta"] > 1, use k theta values:
         if self.surrogate_control["n_theta"] > 1:
@@ -361,13 +315,6 @@ class Spot:
                 counter=self.design_control["init_size"] * self.design_control["repeats"] - 1,
             )
 
-        # Optimizer related information:
-        self.optimizer = optimizer
-        self.optimizer_control = {"max_iter": 1000, "seed": 125}
-        self.optimizer_control.update(optimizer_control)
-        if self.optimizer is None:
-            self.optimizer = optimize.differential_evolution
-
         # Internal attributes:
         self.X = None
         self.y = None
@@ -384,6 +331,7 @@ class Spot:
         logger.setLevel(self.log_level)
         logger.info(f"Starting the logger at level {self.log_level} for module {__name__}:")
         logger.debug("In Spot() init(): fun_control: %s", self.fun_control)
+        logger.debug("In Spot() init(): design_control: %s", self.design_control)
         logger.debug("In Spot() init(): optimizer_control: %s", self.optimizer_control)
         logger.debug("In Spot() init(): surrogate_control: %s", self.surrogate_control)
         logger.debug("In Spot() init(): self.get_spot_attributes_as_df(): %s", self.get_spot_attributes_as_df())
@@ -414,19 +362,21 @@ class Spot:
                 from math import inf
                 from spotPython.fun.objectivefunctions import analytical
                 from spotPython.spot import spot
+                                from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                 # number of initial points:
                 ni = 7
                 # number of points
                 n = 10
                 fun = analytical().fun_sphere
-                lower = np.array([-1])
-                upper = np.array([1])
-                design_control={"init_size": ni}
+                fun_control = fun_control_init(
+                    lower = np.array([-1]),
+                    upper = np.array([1])
+                    fun_evals=n)
+                design_control=design_control_init(init_size=ni)
                 spot_1 = spot.Spot(fun=fun,
-                            lower = lower,
-                            upper= upper,
-                            fun_evals = n,
-                            show_progress=True,
+                            fun_control=fun_control,
                             design_control=design_control,)
                 spot_1.run()
                 df = spot_1.get_spot_attributes_as_df()
@@ -505,19 +455,21 @@ class Spot:
             >>> import numpy as np
                 from spotPython.fun.objectivefunctions import analytical
                 from spotPython.spot import spot
+                                from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                 # number of initial points:
                 ni = 3
                 # number of points
                 n = 10
                 fun = analytical().fun_sphere
-                lower = np.array([-1, -1])
-                upper = np.array([1, 1])
-                design_control={"init_size": ni}
+                fun_control = fun_control_init(
+                    lower = np.array([-1, -1]),
+                    upper = np.array([1, 1]),
+                    fun_evals = n)
+                design_control=design_control_init(init_size=ni)
                 spot_1 = spot.Spot(fun=fun,
-                            lower = lower,
-                            upper= upper,
-                            fun_evals = n,
-                            show_progress=True,
+                            fun_control=fun_control,
                             design_control=design_control,)
                 spot_1.run()
                 assert spot_1.lower.size == 2
@@ -593,6 +545,9 @@ class Spot:
         Examples:
             >>> import numpy as np
                 from spotPython.fun.objectivefunctions import analytical
+                               from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                 from spotPython.spot import spot
                 from spotPython.utils.init import fun_control_init
                 # number of initial points:
@@ -600,22 +555,15 @@ class Spot:
                 X_start = np.array([[0, 1], [1, 0], [1, 1], [1, 1]])
                 fun = analytical().fun_sphere
                 fun_control = fun_control_init(
-                        sigma=0.0,
-                        seed=123,)
-                lower = np.array([-1, -1])
-                upper = np.array([1, 1])
-                design_control={"init_size": ni,
-                                "repeats": 1}
-                S = spot.Spot(fun=fun,
-                            noise=False,
-                            fun_repeats=1,
                             n_points=10,
                             ocba_delta=0,
-                            lower = lower,
-                            upper= upper,
-                            show_progress=True,
-                            design_control=design_control,
-                            fun_control=fun_control
+                            lower = np.array([-1, -1]),
+                            upper = np.array([1, 1])
+                )
+                design_control=design_control_init(init_size=ni)
+                S = spot.Spot(fun=fun,
+                                fun_control=fun_control
+                                design_control=design_control,
                 )
                 S.initialize_design(X_start=X_start)
                 S.update_stats()
@@ -709,18 +657,20 @@ class Spot:
             >>> import numpy as np
                 from spotPython.fun.objectivefunctions import analytical
                 from spotPython.spot import spot
+                from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                 # number of initial points:
                 ni = 7
                 # start point X_0
                 X_start = np.array([[0, 0], [0, 1], [1, 0], [1, 1]])
                 fun = analytical().fun_sphere
-                lower = np.array([-1, -1])
-                upper = np.array([1, 1])
-                design_control={"init_size": ni}
+                fun_control = fun_control_init(
+                    lower = np.array([-1, -1]),
+                    upper = np.array([1, 1]))
+                design_control=design_control_init(init_size=ni)
                 S = spot.Spot(fun=fun,
-                            lower = lower,
-                            upper= upper,
-                            show_progress=True,
+                            fun_control=fun_control,
                             design_control=design_control,)
                 S.initialize_design(X_start=X_start)
                 print(f"S.X: {S.X}")
@@ -801,19 +751,21 @@ class Spot:
             >>> # 1. Without OCBA points:
             >>> import numpy as np
                 from spotPython.fun.objectivefunctions import analytical
+                from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                 from spotPython.spot import spot
                 # number of initial points:
                 ni = 0
                 X_start = np.array([[0, 0], [0, 1], [1, 0], [1, 1], [1, 1]])
                 fun = analytical().fun_sphere
-                lower = np.array([-1, -1])
-                upper = np.array([1, 1])
-                design_control={"init_size": ni}
+                fun_control = fun_control_init(
+                    lower = np.array([-1, -1]),
+                    upper = np.array([1, 1])
+                    )
+                design_control=design_control_init(init_size=ni)
                 S = spot.Spot(fun=fun,
-                            noise=False,
-                            lower = lower,
-                            upper= upper,
-                            show_progress=True,
+                            fun_control=fun_control,
                             design_control=design_control,)
                 S.initialize_design(X_start=X_start)
                 print(f"S.X: {S.X}")
@@ -842,19 +794,14 @@ class Spot:
                 fun = analytical().fun_sphere
                 fun_control = fun_control_init(
                         sigma=0.02,
-                        seed=123,)
-                lower = np.array([-1, -1])
-                upper = np.array([1, 1])
-                design_control={"init_size": ni,
-                                "repeats": 2}
+                        lower = np.array([-1, -1]),
+                        upper = np.array([1, 1]),
+                        noise=True,
+                        ocba_delta=1,
+                    )
+                design_control=design_control_init(init_size=ni, repeats=2)
+
                 S = spot.Spot(fun=fun,
-                            noise=True,
-                            fun_repeats=2,
-                            n_points=1,
-                            ocba_delta=1,
-                            lower = lower,
-                            upper= upper,
-                            show_progress=True,
                             design_control=design_control,
                             fun_control=fun_control
                 )
@@ -933,18 +880,20 @@ class Spot:
                 >>> import numpy as np
                     from spotPython.fun.objectivefunctions import analytical
                     from spotPython.spot import spot
+                    from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                     # number of initial points:
                     ni = 0
                     X_start = np.array([[0, 0], [0, 1], [1, 0], [1, 1], [1, 1]])
                     fun = analytical().fun_sphere
-                    lower = np.array([-1, -1])
-                    upper = np.array([1, 1])
-                    design_control={"init_size": ni}
+                    fun_control = fun_control_init(
+                        lower = np.array([-1, -1]),
+                        upper = np.array([1, 1])
+                        )
+                    design_control=design_control_init(init_size=ni)
                     S = spot.Spot(fun=fun,
-                                noise=False,
-                                lower = lower,
-                                upper= upper,
-                                show_progress=True,
+                                fun_control=fun_control,
                                 design_control=design_control,)
                     S.initialize_design(X_start=X_start)
                     S.update_stats()
@@ -999,6 +948,7 @@ class Spot:
         self.min_y = min(self.y)
         self.min_X = self.X[argmin(self.y)]
         self.counter = self.y.size
+        self.fun_control.update({"counter": self.counter})
         # Update aggregated x and y values (if noise):
         if self.noise:
             Z = aggregate_mean_var(X=self.X, y=self.y)
@@ -1069,14 +1019,20 @@ class Spot:
             >>> import numpy as np
                 from spotPython.spot import spot
                 from spotPython.fun.objectivefunctions import analytical
+                from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                 nn = 3
                 fun_sphere = analytical().fun_sphere
+                fun_control = fun_control_init(
+                        lower = np.array([-1, -1]),
+                        upper = np.array([1, 1]),
+                        n_points=nn,
+                        )
                 spot_1 = spot.Spot(
                     fun=fun_sphere,
-                    lower=np.array([-1, -1]),
-                    upper=np.array([1, 1]),
-                    n_points=nn,
-                )
+                    fun_control=fun_control,
+                    )
                 # (S-2) Initial Design:
                 spot_1.X = spot_1.design.scipy_lhd(
                     spot_1.design_control["init_size"], lower=spot_1.lower, upper=spot_1.upper
@@ -1181,22 +1137,24 @@ class Spot:
             >>> import numpy as np
                 from spotPython.fun.objectivefunctions import analytical
                 from spotPython.spot import spot
+                from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                 # number of initial points:
                 ni = 7
                 # number of points
                 fun_evals = 10
                 fun = analytical().fun_sphere
-                lower = np.array([-1, -1])
-                upper = np.array([1, 1])
-                design_control={"init_size": ni}
-                surrogate_control={"n_theta": 3}
+                fun_control = fun_control_init(
+                    lower = np.array([-1, -1]),
+                    upper = np.array([1, 1])
+                    fun_evals=fun_evals,
+                    tolerance_x = np.sqrt(np.spacing(1))
+                    )
+                design_control=design_control_init(init_size=ni)
+                surrogate_control=surrogate_control_init(n_theta=3)
                 S = spot.Spot(fun=fun,
-                            lower = lower,
-                            upper= upper,
-                            log_level = 50,
-                            fun_evals = fun_evals,
-                            tolerance_x = np.sqrt(np.spacing(1)),
-                            show_progress=True,
+                            fun_control=fun_control
                             design_control=design_control,
                             surrogate_control=surrogate_control,)
                 S.run()
@@ -1245,6 +1203,9 @@ class Spot:
 
         Examples:
             >>> import numpy as np
+                from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                 from spotPython.fun.objectivefunctions import analytical
                 from spotPython.spot import spot
                 # number of initial points:
@@ -1252,19 +1213,17 @@ class Spot:
                 # number of points
                 fun_evals = 7
                 fun = analytical().fun_sphere
-                lower = np.array([-1])
-                upper = np.array([1])
-                design_control={"init_size": ni}
-                surrogate_control={"n_theta": 1}
+                fun_control = fun_control_init(
+                    lower = np.array([-1]),
+                    upper = np.array([1]),
+                    fun_evals=fun_evals,
+                    tolerance_x = np.sqrt(np.spacing(1))
+                    )
+                design_control=design_control_init(init_size=ni)
+
                 S = spot.Spot(fun=fun,
-                            lower = lower,
-                            upper= upper,
-                            log_level = 50,
-                            fun_evals = fun_evals,
-                            tolerance_x = np.sqrt(np.spacing(1)),
-                            show_progress=True,
-                            design_control=design_control,
-                            surrogate_control=surrogate_control,)
+                            fun_control=fun_control,
+                            design_control=design_control
                 S.run()
                 S.plot_model()
         """
@@ -1373,13 +1332,16 @@ class Spot:
                 >>> import numpy as np
                     from spotPython.fun.objectivefunctions import analytical
                     from spotPython.spot import spot
-                    fun = analytical().fun_sphere
-                    lower = np.array([-1, -1])
-                    upper = np.array([1, 1])
-                    S = spot.Spot(fun=fun,
-                                lower = lower,
-                                upper= upper,
+                    from spotPython.utils.init import (
+                        fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
                     )
+                    fun = analytical().fun_sphere
+                    fun_control = fun_control_init(
+                        lower = np.array([-1]),
+                        upper = np.array([1]),
+                    )
+                    S = spot.Spot(fun=fun,
+                                func_control=fun_control)
                     z0 = [1, 2, 3]
                     print(f"Before: {z0}")
                     new_val_1 = 4
@@ -1427,22 +1389,24 @@ class Spot:
             >>> import numpy as np
                 from spotPython.fun.objectivefunctions import analytical
                 from spotPython.spot import spot
+                from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                 # number of initial points:
                 ni = 5
                 # number of points
                 fun_evals = 10
                 fun = analytical().fun_sphere
-                lower = np.array([-1, -1, -1])
-                upper = np.array([1, 1, 1])
-                design_control={"init_size": ni}
-                surrogate_control={"n_theta": 3}
+                fun_control = fun_control_init(
+                    lower = np.array([-1, -1, -1]),
+                    upper = np.array([1, 1, 1]),
+                    fun_evals=fun_evals,
+                    tolerance_x = np.sqrt(np.spacing(1))
+                    )
+                design_control=design_control_init(init_size=ni)
+                surrogate_control=surrogate_control_init(n_theta=3)
                 S = spot.Spot(fun=fun,
-                            lower = lower,
-                            upper= upper,
-                            log_level = 50,
-                            fun_evals = fun_evals,
-                            tolerance_x = np.sqrt(np.spacing(1)),
-                            show_progress=True,
+                            fun_control=fun_control,
                             design_control=design_control,
                             surrogate_control=surrogate_control,)
                 S.run()
@@ -1508,22 +1472,24 @@ class Spot:
             >>> import numpy as np
                 from spotPython.fun.objectivefunctions import analytical
                 from spotPython.spot import spot
+                from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                 # number of initial points:
                 ni = 5
                 # number of points
                 fun_evals = 10
                 fun = analytical().fun_sphere
-                lower = np.array([-1, -1, -1])
-                upper = np.array([1, 1, 1])
-                design_control={"init_size": ni}
-                surrogate_control={"n_theta": 3}
+                fun_control = fun_control_init(
+                    lower = np.array([-1, -1, -1]),
+                    upper = np.array([1, 1, 1]),
+                    fun_evals=fun_evals,
+                    tolerance_x = np.sqrt(np.spacing(1))
+                    )
+                design_control=design_control_init(init_size=ni)
+                surrogate_control=surrogate_control_init(n_theta=3)
                 S = spot.Spot(fun=fun,
-                            lower = lower,
-                            upper= upper,
-                            log_level = 50,
-                            fun_evals = fun_evals,
-                            tolerance_x = np.sqrt(np.spacing(1)),
-                            show_progress=True,
+                            fun_control=fun_control,
                             design_control=design_control,
                             surrogate_control=surrogate_control,)
                 S.run()
@@ -1648,22 +1614,24 @@ class Spot:
             >>> import numpy as np
                 from spotPython.fun.objectivefunctions import analytical
                 from spotPython.spot import spot
+                from spotPython.utils.init import (
+                    fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+                    )
                 # number of initial points:
                 ni = 5
                 # number of points
                 fun_evals = 10
                 fun = analytical().fun_sphere
-                lower = np.array([-1, -1, -1])
-                upper = np.array([1, 1, 1])
-                design_control={"init_size": ni}
-                surrogate_control={"n_theta": 3}
+                fun_control = fun_control_init(
+                    lower = np.array([-1, -1, -1]),
+                    upper = np.array([1, 1, 1]),
+                    fun_evals=fun_evals,
+                    tolerance_x = np.sqrt(np.spacing(1))
+                    )
+                design_control=design_control_init(init_size=ni)
+                surrogate_control=surrogate_control_init(n_theta=3)
                 S = spot.Spot(fun=fun,
-                            lower = lower,
-                            upper= upper,
-                            log_level = 50,
-                            fun_evals = fun_evals,
-                            tolerance_x = np.sqrt(np.spacing(1)),
-                            show_progress=True,
+                            fun_control=fun_control,
                             design_control=design_control,
                             surrogate_control=surrogate_control,)
                 S.run()
